pecos.qeclib.steane.syn\_extract
================================

.. automodule:: pecos.qeclib.steane.syn_extract



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeclib.steane.syn_extract.six_check_nonflagging
   pecos.qeclib.steane.syn_extract.three_parallel_flagging
